@@ -23,7 +23,8 @@ from ._utils import (
     _get_insight_name,
     _get_create_hashname,
     _gzip_dir,
-    _execute_iterator
+    _execute_iterator,
+    _in_virtualenv
 )
 from ._version import __version__
 from . import templates
@@ -105,11 +106,16 @@ def _init():
         f.writelines(
             ["# This is where you can write the required pip installs for your tracking functions"])
 
-    for output in _execute_iterator("python3 -m venv .venv"):
-        logger.info(output)
+    if not _in_virtualenv():  # in venv -> True
+        for output in _execute_iterator("python3 -m venv .venv"):
+            logger.info(output)
 
-    logger.info(
-        "READY! You can activate your virtual environment with 'source ./.venv/bin/activate'. Happy coding!")
+        logger.info(
+            "READY! You can activate your virtual environment with 'source ./.venv/bin/activate'. Happy coding!")
+    else:
+        logger.info(
+            "Active virtual environment detected; skipping virtual env creation!")
+        logger.info("READY!")
 
 
 def _deploy(test):
