@@ -1,8 +1,10 @@
-import idk
 from idk.insight import InsightGenerator
 from idk.io import InsightData
+import plotly.graph_objects as go
 import pandas as pd
 
+from typing import Union
+
 
 class _DeveloperInsight_(InsightGenerator):
 
@@ -56,14 +58,17 @@ class _DeveloperInsight_(InsightGenerator):
         """
 
         return InsightData(
-            # It can be useful to automatically tag your insights contents, think subjects and entities
+            # What category is this insight pertaining to
+            categories=[],
+            # It can be useful to automatically tag your insights contents, think meta-subjects and entities
             tags=[],
             # From 0-1, how important is the data generated in this insight relative to other instances of the same insight?
             significance=0.0,
-            data=dict(),            # This where you store the data you've generated and you want to pass to your transcribe function in ./transcription/transcribe.py
+            # This where you store the data you've generated and you want to pass to your transcribe function in ./transcription/transcribe.py
+            data=dict(),
         )
 
-    def provide_evidence(self, data: pd.DataFrame) -> str:
+    def provide_evidence(self, data: pd.DataFrame) -> go.Figure:
         """This function is where you can provide evidence of your insights correctness as a data plot. The main aim of this plot
         is to convince your targeted user that your insight is accurate enough for them to action on.
 
@@ -91,3 +96,4 @@ class _DeveloperInsight_(InsightGenerator):
 
         [OPTIONAL] You need to provide this evidence piece for it to go into production.
         """
+        return None
