@@ -1,6 +1,7 @@
+from idk.io import TranscribeData
 
 
-def transcribe(payload: dict) -> str:
+def transcribe(payload: dict) -> TranscribeData:
     """Your code goes under here!
 
     Args:
